SystemOrganization addCategory: #'Zinc-Tests'!

TestCase subclass: #ZnBivalentWriteStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWriting
	| string |
	string := String streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray ].
	self assert: string asByteArray = #(97 98 99) asByteArray! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWritingToTranscript
	| writeStream |
	writeStream := ZnBivalentWriteStream on: Transcript.
	writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray
! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 21:02'!
testCharacterWriting
	| bytes |
	bytes := ByteArray streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: $a; space; nextPutAll: '123' ].
	self assert: bytes = 'a 123' asByteArray! !

TestCase subclass: #ZnBufferedWriteStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnBufferedWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2010 09:54'!
testWriting
	| string |
	string := String streamContents: [ :stringStream | | bufferedStream |
		bufferedStream := ZnBufferedWriteStream on: stringStream.
		0 to: 9 do: [ :each | bufferedStream nextPut: (Character digitValue: each) ].
		bufferedStream flush ].
	self assert: string = '0123456789'! !

!ZnBufferedWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2010 09:53'!
testWritingOverflow
	| string |
	string := String streamContents: [ :stringStream | | bufferedStream |
		bufferedStream := ZnBufferedWriteStream on: stringStream.
		bufferedStream sizeBuffer: 8.
		0 to: 9 do: [ :each | bufferedStream nextPut: (Character digitValue: each) ].
		bufferedStream nextPutAll: '0123'; nextPutAll: '4567'; nextPutAll: '89'.
		bufferedStream nextPutAll: '0123456789'; nextPutAll: '0123456789'.
		bufferedStream flush ].
	self assert: string = '0123456789012345678901234567890123456789'! !

TestCase subclass: #ZnCharacterEncoderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnCharacterEncoderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/30/2010 11:57'!
decodeBytes: bytes with: encoder
	| input |
	input := bytes readStream.
	^ String streamContents: [ :stream |
		[ input atEnd ] whileFalse: [ 
			stream nextPut: (encoder nextFromStream: input) ] ]! !

!ZnCharacterEncoderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/30/2010 11:57'!
encodeString: string with: encoder
	^ ByteArray streamContents: [ :stream |
		string do: [ :each |
			encoder nextPut: each toStream: stream ] ]! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testLatin2Encoder
	"Example characters taken from http://en.wikipedia.org/wiki/Latin2"
	
	| encoder inputBytes outputBytes inputString outputString |
	encoder := ZnCharacterEncoder newForEncoding: 'latin2'.
	inputString := String 
		with: (16r0154 asCharacter) with: (16r0110 asCharacter) 
		with: ( 16r0155 asCharacter) with: (16r0111 asCharacter).
	inputBytes := #(192 208 224 240) asByteArray.
	outputBytes := self encodeString: inputString with: encoder.
	self assert: outputBytes = inputBytes.
	outputString := self decodeBytes: inputBytes with: encoder.
	self assert: outputString = inputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:45'!
testNullEncoder
	| encoder bytes string |
	encoder := ZnNullEncoder new.
	bytes := self encodeString: 'abc' with: encoder.
	self assert: bytes = #(97 98 99) asByteArray.
	string := self decodeBytes: #(65 66 67) asByteArray with: encoder.
	self assert: string = 'ABC' ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testUTF8Encoder
	"The examples are taken from http://en.wikipedia.org/wiki/UTF-8#Description"
	
	| encoder inputBytes outputBytes inputString outputString |
	encoder := ZnUTF8Encoder new.
	inputString := String with: $$ with: (16r00A2 asCharacter) with: (16r20AC asCharacter) with: (16r024B62 asCharacter).
	inputBytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	outputBytes := self encodeString: inputString with: encoder.
	self assert: outputBytes = inputBytes.
	outputString := self decodeBytes: inputBytes with: encoder.
	self assert: outputString = inputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/30/2010 13:42'!
testUTF8EncoderAuto
	| encoder inputString bytes outputString |
	encoder := ZnUTF8Encoder new.
	inputString := String withAll: ((1 to: 3072) collect: [ :each | Character value: each ]).
	bytes := self encodeString: inputString with: encoder. 
	outputString := self decodeBytes: bytes with: encoder.
	self assert: inputString = outputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testUTF8EncoderByteCount	
	| encoder |
	encoder := ZnUTF8Encoder new.
	self assert: (encoder encodedByteCountFor: $$) = 1.
	self assert: (encoder encodedByteCountFor: (16r00A2 asCharacter)) = 2.
	self assert: (encoder encodedByteCountFor: (16r20AC asCharacter)) = 3.
	self assert: (encoder encodedByteCountFor: (16r024B62 asCharacter)) = 4! !

TestCase subclass: #ZnChunkedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:07'!
testReading
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:18'!
testReadingGzip
	| data gzipped chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	plain := (GZipReadStream on: (ZnChunkedReadStream on: chunked readStream)) upToEnd.
	self assert: data = plain ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:17'!
testReadingGzipStepped
	| data gzipped chunked unchunked ungzipped |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	unchunked := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	ungzipped := (GZipReadStream on: unchunked) upToEnd.
	self assert: gzipped = unchunked.
	self assert: data = ungzipped ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2011 17:39'!
testReadingNext
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) next: 26 + 26.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2011 17:40'!
testReadingNextInto
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := String new: 26 + 26.
	(ZnChunkedReadStream on: chunked readStream) next: 26 + 26 into: plain.
	self assert: plain = data! !

TestCase subclass: #ZnClientOldTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnClientOldTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:11'!
testGet
	| response |
	response := [ ZnClientOld get: 'http://zn.stfx.eu/zn/small.html' ]
		on: Deprecation do: [ :ex | ex resume ].
	self assert: response isSuccess! !

TestCase subclass: #ZnClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:15'!
port
	^ 1700 + 10 atRandom! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testConstruction
	| client |
	(client := ZnClient new)
		http;
		host: 'www.example.com';
		port: 8080;
		addPath: 'foo';
		addPath: 'a space';
		addPath: 'file.txt';
		queryAt: 'key' put: '123456';
		headerAt: 'X-token' put: 'ABCDEF'.
	self assert: client request url host = 'www.example.com'.
	self assert: client request url port = 8080.
	self assert: client request url pathQueryFragmentPrintString = '/foo/a%20space/file.txt?key=123456'.
	self assert: (client request headers at: 'X-token') = 'ABCDEF'! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:13'!
testCookies
	| client |
	self withServerDo: [ :server |
		server delegate: (ZnValueDelegate with: [ :request | | cookie1 cookie2 response |
			cookie1 := request cookies detect: [ :each | each name = 'x' ] ifNone: [ ZnCookie name: 'x' value: '0' ].
			cookie2 := request cookies detect: [ :each | each name = 'y' ] ifNone: [ ZnCookie name: 'y' value: '100' ].
			cookie1 value: (cookie1 value asInteger + 1) asString.
			cookie2 value: (cookie2 value asInteger + 2) asString.
			response := ZnResponse ok: (ZnEntity text: 'OK').
			response addCookie: cookie1; addCookie: cookie2.
			response ]).
		client := ZnClient new url: server localUrl; yourself.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) isNil.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) isNil.
		client get.
		self assert: client isSuccess.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) value = '1'.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) value = '102'.
		client get.
		self assert: client isSuccess.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) value = '2'.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) value = '104'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:13'!
testGetAfterPost
	self withServerDo: [ :server | | client |
		server delegate: (ZnValueDelegate with: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [
					self assert: (request method = #POST).
					self assert: request hasEntity. 
					ZnResponse ok: (ZnEntity text: 'OK for one') ]
				ifFalse: [
					request uri firstPathSegment = 'two'
						ifTrue: [ 
							self assert: (request method = #GET).
							self deny: request hasEntity.
							ZnResponse ok: (ZnEntity text: 'OK for two') ]
		 				ifFalse: [ ZnResponse notFound: request uri ] ] ] ).
		(client := ZnClient new) 
			url: server localUrl;
			url: 'one';
			entity: (ZnEntity text: 'One two three');
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK for one'.
		client
			url: 'two';
			get.
		self assert: client isSuccess.
		self assert: client contents = 'OK for two'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetGeoIP
	| result client |
	result := (client := ZnClient new)
		systemPolicy;
		url: 'http://easy.t3-platform.net/rest/geo-ip';
		queryAt: 'address' put: '81.83.7.35';
		accept: ZnMimeType applicationJson;
		contentReader: [ :entity | | parserClass |
			parserClass := Smalltalk at: #JSJsonParser ifAbsent: [ ^ self ].
			parserClass parse: entity contents ];
		ifFail: [ ^ self fail ];
		get.
	self assert: result isDictionary.
	self assert: (result at: #country) = 'BE'.
	client close.! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetSmallHTML
	| client |
	(client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client isContentTypeAcceptable.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'Small').
	self assert: client isConnected.
	client close.
	self deny: client isConnected! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetSmallHTMLOneShot
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'Small').
	self deny: client isConnected! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetSmallHTMLStreaming
	| client result contents |
	result := (client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		streaming: true;
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: result isStream.
	self assert: client entity stream = result.
	contents := result upToEnd.
	self assert: (contents includesSubString: 'Small').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetSmallHTMLTwice
	| client |
	(client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'Small').
	client 
		url: '/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'Small').
	client close.
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetSmallHTMLUrlConstruction
	| client |
	(client := ZnClient new)
		http;
		host: 'zn.stfx.eu';
		path: '/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'Small').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:13'!
testHeadSmallHTML
	| client |
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			head.
		self assert: client isSuccess.
		self assert: client response contentLength > 0.
		self assert: client response hasEntity not.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailNonExistingHost
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://unknown-stfx.eu';
		ifFail: [ : exception |
			^ self assert: (exception isKindOf: NetworkError) ];
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailNotFound
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://stfx.eu/non-existing';
		ifFail: [ :exception |
			^ self assert: (exception isKindOf: ZnHttpUnsuccessful) ];
		get.
	self assert: client isSuccess not.
	client
		enforceHttpSuccess: true;
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailWrongType
	| client |
	(client := ZnClient new)
		beOneShot;
		accept: ZnMimeType imagePng;
		enforceAcceptContentType: true;
		url: 'http://zn.stfx.eu/zn/small.html';
		ifFail: [ :exception |
			^ self assert: (exception isKindOf: ZnUnexpectedContentType) ];
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfModifiedSinceNotModified
	| client request response |
	(client := ZnClient new) host: 'caretaker.wolf359.be'.
	[
		response := client 
			url: '/small.html'; 
			setIfModifiedSince: (Date year: 2011 month: 1 day: 1);
			get; 
			response.
		self assert: response isNotModified.
		self assert: response hasEntity not ] ensure: [ client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testLogging
	| client memoryLogger |
	memoryLogger := ZnMemoryLogger new.
	(client := ZnClient new)
		beOneShot.
	client log addListener: memoryLogger.
	client	get: 'http://zn.stfx.eu/zn/small.html'.
	client close.
	self deny: memoryLogger logEvents isEmpty! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:13'!
testPostForm
	| client |
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			formAt: 'username' put: 'john';
			formAdd: 'password' -> 'secret';
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubString: 'john').
		self assert: (client contents includesSubString: 'secret') ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'CamilloBruni 5/4/2012 20:49'!
testPostMultipart
	| client file |
	file := FileSystem disk workingDirectory  / 'testPostMultiPart.txt'.
	file writeStreamDo: [ :stream | stream nextPutAll: '0123456789' ].
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			addPart: (ZnMimePart fieldName: 'username' value: 'john');
			addPart: (ZnMimePart fieldName: 'foo' entity: (ZnEntity text: '123'));
			addPart: (ZnMimePart fieldName: 'file' fileNamed: file fullName);
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubString: 'multipart') ].
	file delete.! !

!ZnClientTests methodsFor: 'testing' stamp: 'SeanDeNigris 6/21/2012 09:27'!
testProgress
	"UIManager default informUserDuring: [ :bar |
		[ ^ ZnClient new
				signalProgress: true;
				get: 'http://zn.stfx.eu/echo?delay=2' ]
			on: HTTPProgress 
			do: [ :progress | bar label: progress printString. progress resume ] ]"
		
	self 
		should: [ 
			ZnClient new
				beOneShot;
				signalProgress: true;
				get: 'http://zn.stfx.eu/zn/small.html' ] 
		raise: HTTPProgress
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/20/2011 13:55'!
testProgressNoIfFail
	self 
		should: [ 
			ZnClient new
				beOneShot;
				signalProgress: true;
				ifFail: [ self fail ];
				get: 'http://zn.stfx.eu/zn/small.html' ] 
		raise: HTTPProgress
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testQueryGoogle
	| client |
	(client := ZnClient new)
		http;
		host: 'www.google.com';
		addPath: 'search';
		queryAt: 'q' put: 'Pharo Smalltalk';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubString: 'pharo-project.org').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testRedirect
	| client response |
	client := ZnClient new url: 'http://www.pharo-project.org'.
	self assert: (client get; isSuccess).
	client 
		close;
		maxNumberOfRedirects: 0;
		url: 'http://www.pharo-project.org'.
	self should: [ client get ] raise: ZnTooManyRedirects.
	client close.
	response := [ ZnClient new beOneShot; maxNumberOfRedirects: 0; get: 'http://www.pharo-project.org'; response ]
		on: ZnTooManyRedirects do: [ :exception | exception resume ].
	self assert: response isRedirect ! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/23/2011 17:13'!
testRedirectDontFollow
	| client |
	(client := ZnClient new) 
		dontFollowRedirects;
		get: 'http://www.pharo-project.org'.
	self assert: client response isRedirect.
	client
		enforceHttpSuccess: true;
		get: 'http://www.pharo-project.org'.
	self assert: client response isRedirect.
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:14'!
testRedirectWithCookies
	self withServerDo: [ :server | | client cookie |
		server delegate: (ZnValueDelegate with: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [ 
					(ZnResponse redirect: 'two')
						addCookie: (ZnCookie name: 'session' value: '123456');
						yourself ]
				ifFalse: [
					cookie := request cookies detect: [ :each | each name = 'session' ] ifNone: [ nil ].
					(request uri firstPathSegment = 'two' and: [ cookie notNil and: [ cookie value = '123456' ] ])
						ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 				ifFalse: [ ZnResponse badRequest: request ] ] ] ).
		(client := ZnClient new) 
			url: server localUrl; addPath: 'one'; 
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK!!'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:14'!
testRelativeRedirect
	self withServerDo: [ :server | | client |
		server delegate: (ZnValueDelegate with: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [ ZnResponse redirect: 'two' ]
				ifFalse: [
					request uri firstPathSegment = 'two'
						ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 				ifFalse: [ ZnResponse notFound: request uri ] ] ] ).
		(client := ZnClient new) 
			url: server localUrl; addPath: 'one'; 
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK!!'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:14'!
testTimeout
	self withServerDo: [ :server |
		self 
			should: [ 
				ZnClient new 
					timeout: 1; 
					url: server localUrl;
					addPath: 'echo';
					queryAt: 'delay' put: '2'; 
					get ]
			raise: ConnectionTimedOut ]! !

!ZnClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 8/31/2011 21:59'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnCredentialTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnCredentialTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 10/4/2011 14:11'!
ignoringDeprecation: block
	[ block value ] 
		on: Deprecation 
		do: [ :exception | exception resume ]! !

!ZnCredentialTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:32'!
port
	^ 1700 + 10 atRandom! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:34'!
testBasicAuthorization
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client cred |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnUserAgent new.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
			cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
				username: 'foo';
				password: 'secret';
				domain: client request url authority;
				yourself.
			cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
			client session addCredential: cred.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response statusLine code = 200 ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:37'!
testBasicAuthorizationFailure
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client cred |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnUserAgent new.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
			cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
				username: 'foo';
				password: 'wrong';
				domain: client request url authority;
				yourself.
			cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
			client session addCredential: cred.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response statusLine code = 401 ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:38'!
testDigestAuthorization
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client cred |
			self
				assert: ZnDigestAuthenticator hasMD5Support
				description: 'MD5 hashing support is required for Digest authentication.'.
			server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
			client := ZnUserAgent new.	
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
			cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
				username: 'foo';
				password: 'secret';
				domain: client request url authority;
				yourself.
			cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
			client session addCredential: cred.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response statusLine code = 200 ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:39'!
testDigestAuthorizationFailure
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client cred |
			self
				assert: ZnDigestAuthenticator hasMD5Support
				description: 'MD5 hashing support is required for Digest authentication.'.
			server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
			client := ZnUserAgent new.	
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
			cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
				username: 'foo';
				password: 'wrong';
				domain: client request url authority;
				yourself.
			cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
			client session addCredential: cred.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response statusLine code = 401 ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:39'!
testFindHandlerFor
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client handler |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnUserAgent new.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
			handler := ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate').
			self assert: handler = ZnBasicCredential ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:40'!
testFindRealmFor
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client realm |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnUserAgent new.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
			realm := ZnCredential findRealmFor: (response headers at: 'WWW-Authenticate').
			self assert: (realm includesSubString: 'Zinc') ] ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:41'!
testZnServerBasicAuthRealm
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client cred |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
			client := ZnUserAgent new.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 401.
			self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
			cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
				username: 'foo';
				password: 'secret';
				domain: client request url authority;
				yourself.
			cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
			self assert: cred realm = 'TEST'.
			client session addCredential: cred.
			response := client get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response statusLine code = 200 ] ]! !

!ZnCredentialTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:32'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnDispatcherDelegateTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnDispatcherDelegateTest methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:10'!
port
	^ 1700 + 10 atRandom! !

!ZnDispatcherDelegateTest methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:13'!
testDispatcherDelegate
	self withServerDo: [ :server |  | client |
		server delegate: (ZnDispatcherDelegate new 
			map: '/hello' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>hello server</h1>') ];
			map: '/' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>default</h1>') ]).

		client := ZnClient new.
		
		client get: (server localUrl addPathSegment: 'missing'; yourself).
		self assert: (client response contentType = ZnMimeType textPlain).
		self assert: (client response status = 404).
		
		client get: server localUrl.
		self assert: (client response contentType = ZnMimeType textHtml).
		self assert: (client response status = 200).
		
		client get: (server localUrl addPathSegment: 'hello'; yourself).
		self assert: (client response contentType = ZnMimeType textHtml).
		self assert: (client response status = 200).
		
		client close ]! !

!ZnDispatcherDelegateTest methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:10'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnEasyTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEasyTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:02'!
port
	^ 1700 + 10 atRandom! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:03'!
testDelete
	self withServerDo: [ :server | | response |
		response := ZnEasy delete: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'DELETE').
		self assert: (response entity string includesSubString: 'foo') ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2011 16:34'!
testGetJpeg
	| url result |
	url := 'http://caretaker.wolf359.be/sun-fire-x2100.jpg'.
	result := ZnEasy getJpeg: url.
	self assert: result isForm! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2011 16:34'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnEasy get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2011 16:34'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnEasy head: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: response hasEntity not! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:05'!
testPost
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
		response := ZnEasy post: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:05'!
testPostUnicodeUtf8
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 0 to: 16r024F do: [ :each | stream nextPut: each asCharacter ] ].
		response := ZnEasy post: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:06'!
testPut
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
		response := ZnEasy put: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'PUT').
		self assert: (response entity string includesSubString: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:07'!
testTimeout
	self withServerDo: [ : server |
		self 
			should: [ 
				ZnConnectionTimeout 
					value: 1 
					during: [ ZnEasy get: (server localUrl addPathSegment: 'echo'; queryAt: 'delay' put: '2'; yourself) ] ] 
			raise: ConnectionTimedOut ]
	! !

!ZnEasyTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:02'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnEntityReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:03'!
testChunked
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:04'!
testChunkedWithExtraHeaders
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, 
		'X-Foo:bar', String crlf, 
		String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'.
	self assert: (headers at: 'X-Foo') = 'bar'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:08'!
testReadStreaming
	| data headers reader entity |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	self assert: entity contents = data! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:13'!
testReadStreamingWriting
	| data headers reader entity output |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	output := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: output = data! !

TestCase subclass: #ZnEntityTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/27/2011 17:15'!
testMultiPartFormDataWriteRead
	| input output bytes |
	input := (ZnMultiPartFormDataEntity new)
		addPart: (ZnMimePart fieldName: 'extra' value: 'my-extra');
		addPart: (ZnMimePart fieldName: 'info' value: 'my-info');
		addPart: (ZnMimePart fieldName: 'file' fileName: 'foo.txt' entity: (ZnEntity text: 'Zinc HTTP Components'));
		yourself.
	self assert: input contentLength notNil.
	self assert: input contentLength > 0.
	self assert: input contentType = ZnMimeType multiPartFormData.
	bytes := ByteArray streamContents: [ :stream | input writeOn: stream ].
	output := (ZnMultiPartFormDataEntity type: input contentType) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.
	output := (ZnMultiPartFormDataEntity type: input contentType length: input contentLength) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.

	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 15:41'!
testReading
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self assert: entity contents isString.
	self assert: entity string = contents.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 13:39'!
testReadingLimited
	| limit contents |
	contents := String new: 1025 withAll: $X.
	limit := ZnConstants maximumEntitySize.
	[
		ZnConstants maximumEntitySize: 1024.
		self should: [
			ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size ]
			raise: ZnEntityTooLarge.
		self should: [
			ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: nil ]
			raise: ZnEntityTooLarge.
	] ensure: [ ZnConstants maximumEntitySize: limit ]! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/14/2010 12:13'!
testStringEntityEncoderInitialization
	| entity response |
	entity := ZnEntity text: 'Regression test'.
	self assert: entity hasEncoder not.
	response := ZnResponse ok: entity.
	self assert: entity hasEncoder.
	ByteArray streamContents: [ :stream | response writeOn: stream ].
	self assert: entity hasEncoder
	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingDetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain length: 10.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingUndetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8Writing
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity text: string.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	bytes := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: bytes = #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 10:11'!
testWritingApplicationUrlEncoding
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity at: 'foo' put: 'bar'.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=bar'.
	self assert: entity contentLength = 7! !

!ZnEntityTests methodsFor: 'testing' stamp: 'NorbertHartl 12/6/2011 18:33'!
testWritingApplicationUrlEncodingWithTextEncodingLatin1
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity contentType charSet: 'iso-8859-1'.
	entity at: 'foo' put: (Character value: 246) asString.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=%F6'.
	self assert: entity contentLength = 7
	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'NorbertHartl 12/6/2011 18:33'!
testWritingApplicationUrlEncodingWithTextEncodingUtf8
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity contentType charSet: 'utf-8'.
	entity at: 'foo' put: (Character value: 246) asString.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=%C3%B6'.
	self assert: entity contentLength = 10! !

TestCase subclass: #ZnFixedClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnFixedClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 10/4/2011 13:55'!
ignoringDeprecation: block
	[ block value ] 
		on: Deprecation 
		do: [ :exception | exception resume ]! !

!ZnFixedClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 10/4/2011 13:55'!
testGetSmallHTMLDocument
	self
		ignoringDeprecation: [ 
			| client response |
			client := ZnFixedClient host: 'homepage.mac.com'.
			[ 
			response := client get: '/svc/Zinc-HTTP-Components/small.html'.
			self assert: response headers contentType = ZnMimeType textHtml.
			self assert: response statusLine code = 200.
			self assert: (response entity string includesSubString: 'small') ]
				ensure: [ client close ] ]! !

!ZnFixedClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 10/4/2011 13:55'!
testIfModifiedSinceNotModified
	self
		ignoringDeprecation: [ 
			| client request response |
			client := ZnFixedClient host: 'caretaker.wolf359.be'.
			[ 
			request := ZnRequest get: (client fixedUrl: '/small.html').
			request setIfModifiedSince: (Date year: 2011 month: 1 day: 1).
			response := client executeRequest: request.
			self assert: response isNotModified.
			self assert: response hasEntity not ]
				ensure: [ client close ] ]! !

TestCase subclass: #ZnHTTPSocketFacadeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/30/2011 13:59'!
testExtendUrlWithArgs
	| url |
	url := ZnHTTPSocketFacade 
		extendUrl: 'http://www.foo.com/bar' 
		withArguments: (Dictionary new
			at: 'x' put: #('1');
			at: 'z' put: #('aaa' 'bbb');
			yourself).
	self assert: url host = 'www.foo.com'.
	self assert: url path = 'bar'.
	self assert: (url queryAt: 'x') = '1'.
	self assert: (url queryAt: 'z') = #('aaa' 'bbb')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:17'!
testGetSmallHTMLDocument
	| mimeDocument |
	mimeDocument := ZnHTTPSocketFacade httpGetDocument: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (mimeDocument contents includesSubString: 'small').
	self assert: (mimeDocument contentType includesSubString: 'text/html')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:18'!
testGetSmallHTMLStream
	| stream |
	stream := ZnHTTPSocketFacade httpGet: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (stream contents includesSubString: 'small')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 22:11'!
testPut
	| server result dataString |
	server := ZnServer on: (1700 + 10 atRandom).
	server authenticator: (ZnBasicAuthenticator username: 'user' password: 'secret').
	dataString := String streamContents: [ :stream | 
		1 to: 67 do: [ :each | stream nextPut: (Character digitValue: each \\ 9) ] ].
	[ 
		server start.
		result := ZnHTTPSocketFacade 
			httpPut: dataString 
			to: (server localUrl addPathSegments: #('echo' 'foo'); yourself)
			user: 'user' 
			passwd: 'secret'.
		self assert: (result beginsWith: 'HTTP/1.1 200 OK').
		self assert: (result includesSubString: '67B')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnHeadersTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:59'!
testMergeValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' put: 'bar=1' ifPresentMerge: [ :old :new | old, ';', new ].
	self assert: (headers at: 'Set-Cookie') = 'foo=1;bar=1'
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:57'!
testMultiValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	self assert: (headers at: 'Set-Cookie') = #('foo=1' 'bar=1')
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 21:03'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues  = #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1') asOrderedCollection 
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:55'!
testNormalization
	| headers |
	headers := ZnHeaders new.
	headers at: 'content-TYPE' put: 'text/plain'.
	self assert: (headers includesKey: 'content-type').
	self assert: (headers includesKey: 'content-TYPE').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	headers at: 'CONTENT-type' put: 'text/html'.
	self assert: (headers at: 'Content-Type') = 'text/html'.

	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:16'!
testReading
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:20'!
testWriting
	| headers string |
	headers := ZnHeaders new 
		at: 'Content-Type' put: 'text/plain'; 
		at: 'Content-Length' put: '128';
		yourself.
	string := String streamContents: [ :stream | headers writeOn: stream ].
	self assert: (string includesSubString: 'Content-Type: text/plain', String crlf).
	self assert: (string includesSubString: 'Content-Length: 128', String crlf).
	self assert: (string occurrencesOf: Character cr) = 2.
	self assert: (string occurrencesOf: Character lf) = 2! !

TestCase subclass: #ZnHttpClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHttpClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 10/4/2011 14:11'!
ignoringDeprecation: block
	[ block value ] 
		on: Deprecation 
		do: [ :exception | exception resume ]! !

!ZnHttpClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:20'!
port
	^ 1700 + 10 atRandom! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testBasicAuthorization
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				auth: 'foo' password: 'secret'.
			response := client get.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client status = 200 ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testBasicAuthorizationFailure
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client |
			server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				auth: 'foo' password: 'wrong'.
			response := client get.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client isAuthenticationRequired ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:23'!
testCookieAt
	self ignoringDeprecation: [ | client response |
		client := ZnHttpClient new url: 'http://www.pharo-project.org'.
		response := client get.
		self assert: (client cookieAt: 'cmsbox') notNil ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testDelete
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response data client |
			data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
			client := ZnHttpClient new url: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			response := client delete.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client status = 200.
			self assert: (response includesSubString: 'DELETE').
			self assert: (response includesSubString: 'DELETE') ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testDigestAuthorization
	self ignoringDeprecation: [
		self withServerDo: [ :server | | response client |
			server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				digestAuth: 'foo' password: 'secret'.
			response := client get.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client status = 200 ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testDigestAuthorizationFailure
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client |
			server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				digestAuth: 'foo' password: 'wrong'.
			response := client get.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client isAuthenticationRequired ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:26'!
testGet
	self ignoringDeprecation: [ | client response |
		client := ZnHttpClient new.
		response := client
			url: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html';
			get.
		self assert: response notNil.
		self assert: client status = 200 ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:27'!
testGetMultParam
	self ignoringDeprecation: [ | client response |
		client := ZnHttpClient new
			url: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html';
			parameterAt: 'test' add: 'value1';
			parameterAt: 'test' add: 'value2'.
		self assert: (client params at: 'test') isArray.
		response := client get.
		self assert: response notNil.
		self assert: client status = 200 ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:32'!
testPost
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response data client |
			data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				parameterAt: 'foo' put: 'bar';
				parameterAt: 'baz' put: 'bang'.
			response := client post.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client status = 200.
			self assert: (response includesSubString: 'POST').
			self assert: (response includesSubString: 'bar') ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:31'!
testPut
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response data client |
			data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
			client := ZnHttpClient new
				url: (server localUrl addPathSegments: #('echo' 'foo'); yourself);
				parameterAt: 'foo' put: 'bar';
				parameterAt: 'baz' put: 'bang'.
			response := client put.
			self assert: client contentType = ZnMimeType textPlain.
			self assert: client status = 200.
			self assert: (response includesSubString: 'PUT') ] ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:34'!
testRelativeRedirect
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client |
			server delegate:
				(ZnValueDelegate with: [ :request | 
					request uri firstPathSegment = 'one'
						ifTrue: [ ZnResponse redirect: 'two' ]
						ifFalse: [ 
							request uri firstPathSegment = 'two'
								ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
								ifFalse: [ ZnResponse notFound: request uri ] ] ]).
			(client := ZnHttpClient new) url: (server localUrl addPathSegment: 'one'; yourself).
			response := client post.
			self assert: response = 'OK!!' ] ]! !

!ZnHttpClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:20'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnLimitedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinary
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = #(0 1 2 3 4) asByteArray! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinaryAll
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: data size.
	self assert: limitedReadStream upToEnd = data! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:49'!
testNext
	| limitedReadStream |
	limitedReadStream := ZnLimitedReadStream on: String new readStream limit: 10.
	self assert: limitedReadStream atEnd.
	self assert: limitedReadStream next isNil.
	limitedReadStream := ZnLimitedReadStream on: 'ABC' readStream limit: 10.
	self assert: limitedReadStream atEnd not.
	self assert: limitedReadStream next = $A.
	self assert: limitedReadStream peek = $B.
	limitedReadStream next.
	self assert: limitedReadStream next = $C.
	self assert: limitedReadStream next isNil.
	self assert: limitedReadStream atEnd
	! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCount
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	self assert: (stream next: 4) = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:26'!
testNextCountInto
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	buffer := String new: 4.
	self assert: (stream next: 4 into: buffer) = '0123'.
	self assert: buffer = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:41'!
testNextCountIntoShort
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	buffer := String new: 6.
	self assert: (stream next: 6 into: buffer) = '01234'
	! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCountShort
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: (stream next: 6) = '01234'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 13:04'!
testSimple
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = '01234'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:45'!
testSimpleEof
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 15.
	self assert: limitedReadStream upToEnd = '0123456789'.
	self assert: limitedReadStream atEnd.
	self assert: limitedReadStream next isNil! !

TestCase subclass: #ZnLineReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:22'!
testBinary
	| input reader |
	input := ('Foo', String crlf, 'Bar', String crlf) asByteArray.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:21'!
testLineTooLong
	| input reader |
	input := (String new: 128) atAllPut: $X.
	reader := (ZnLineReader on: input readStream) limit: 64.
	self should: [ reader nextLine ] raise: ZnLineTooLong  ! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/2/2012 19:18'!
testLineTooLongDefault
	| input reader |
	input := (String new: ZnConstants maximumLineLength + 1) atAllPut: $X.
	reader := ZnLineReader on: input readStream.
	self should: [ reader nextLine ] raise: ZnLineTooLong  ! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:02'!
testSimple
	| input reader |
	input := 'Foo', String crlf, 'Bar', String crlf.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

TestCase subclass: #ZnLogSupportTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 14:59'!
testFilter
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	memoryLogger filter: #info.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport debug: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/13/2011 00:23'!
testLogEvent
	| logEvent now |
	now := TimeStamp now.
	logEvent := ZnLogEvent info: 'Testing'.
	self assert: logEvent timeStamp >= now.
	self assert: logEvent processId isInteger.
	self assert: logEvent category = #info.
	self assert: logEvent message = 'Testing'  ! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 11:42'!
testSimple 
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport removeListener: memoryLogger.
	logSupport info: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

TestCase subclass: #ZnMagicCookieJarTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:25'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:31'!
cookieStringAlt
	^'PREFS=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.pharo-project.org'! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:19'!
testAdd
	| jar count |
	jar := ZnCookieJar new.
	count := jar cookies size.
	jar add: (ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl).
	self assert: ((jar cookies size) = (count + 1))! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:03'!
testCookieAtForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookieAt: 'PREF' forUrl: 'http://www.google.com' asZnUrl) notNil).
	self assert: ((jar cookieAt: 'foobar' forUrl: 'http://www.google.com' asZnUrl) isNil)! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:02'!
testCookiesForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookiesForUrl: 'http://www.google.com' asZnUrl) size = 1)! !

TestCase subclass: #ZnMagicCookieTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:16'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:11'!
cookieStringSubpath
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/test/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testFromString
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl.
	self assert: (cookie name = 'PREF').
	self assert: (cookie path notNil).
	self assert: (cookie domain = '.google.com').
	self assert: (cookie isExpired not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:01'!
testInDomain
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	self assert: (cookie isInDomain: 'http://www.google.com' asZnUrl).
	self assert: (cookie isInDomain: 'http://google.com' asZnUrl).
	self assert: ((cookie isInDomain: 'http://pharo-project.org' asZnUrl) not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testInPath
	| cookie |
	cookie := ZnCookie fromString: self cookieStringSubpath for: 'www.google.com' asZnUrl.
	self assert: (cookie isInPath: 'www.google.com/test/' asZnUrl).
	self assert: ((cookie isInPath: 'www.google.com' asZnUrl) not)
	! !

TestCase subclass: #ZnMimeTypeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 19:59'!
testAsMimeType
	self assert: 'text/plain' asZnMimeType = ZnMimeType textPlain.
	self assert: ZnMimeType applicationOctetStream asZnMimeType = ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/6/2012 11:05'!
testCharset
	| mimeType |
	mimeType := ZnMimeType textPlain.
	self assert: mimeType charSet = 'utf-8'.
	mimeType charSet: 'ascii'.
	self assert: mimeType charSet = 'ascii'.
	mimeType clearCharSet.
	self assert: mimeType charSet isNil.
	mimeType setCharSetUTF8.
	self assert: mimeType charSet = 'utf-8'! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:51'!
testCopying
	| mimeType1 mimeType2 |
	mimeType1 := ZnMimeType textPlain.
	mimeType2 := ZnMimeType textPlain.
	self assert: mimeType1 = mimeType2.
	self assert: mimeType1 parameters = mimeType2 parameters.
	mimeType1 charSet: 'utf-8'.
	self assert: mimeType1 charSet = 'utf-8'.
	mimeType2 charSet: 'latin1'.
	self assert: mimeType2 charSet = 'latin1'.
	self assert: mimeType1 = mimeType2.
	self deny: mimeType1 parameters = mimeType2 parameters.
	self deny: mimeType1 charSet = mimeType2 charSet.
	! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:44'!
testDefault
	self assert: ZnMimeType default = ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/6/2011 20:44'!
testIdentity
	self assert: ZnMimeType textPlain = ZnMimeType textPlain! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/6/2012 11:02'!
testParameters
	| mimeType |
	mimeType := ZnMimeType main: 'text' sub: 'plain'.
	self should: [ mimeType parameterAt: 'foo' ] raise: KeyNotFound.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = #none.
	mimeType parameterAt: 'foo' put: '1'.
	self assert: (mimeType parameterAt: 'foo') = '1'.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = '1'.
	mimeType removeParameter: 'foo'.
	mimeType removeParameter: 'bar'.
	self should: [ mimeType parameterAt: 'foo' ] raise: KeyNotFound.
	self assert: (mimeType parameterAt: 'foo' ifAbsent: [ #none ]) = #none	! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testReading
	| mimeType |
	mimeType := ZnMimeType fromString: 'text/plain; charset=utf-8'.
	self assert: (mimeType main = 'text').
	self assert: (mimeType sub = 'plain').
	self assert: (mimeType charSet = 'utf-8').
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testWriting
	| mimeType |
	(mimeType := ZnMimeType main: 'text' sub: 'plain')
		charSet: 'utf-8'.
	self assert: mimeType printString = 'text/plain;charset=utf-8'.
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

TestCase subclass: #ZnMultiValueDictionaryTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMultiValueDictionaryTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testMultiValues
	| dictionary values keys |
	dictionary := ZnMultiValueDictionary new.
	dictionary at: 'foo' add: 1; at: 'foo' add: 2.
	self assert: (dictionary at: 'foo') = #(1 2).
	self assert: dictionary keys asArray = #('foo').
	values := OrderedCollection new.
	keys := OrderedCollection new.
	dictionary keysAndValuesDo: [ :key :value | keys add: key. values add: value ].
	self assert: values = (OrderedCollection with: 1 with: 2).
	self assert: keys = (OrderedCollection with: 'foo' with: 'foo')
	! !

!ZnMultiValueDictionaryTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/2/2012 19:23'!
testTooManyEntries
	| dictionary |
	dictionary := ZnMultiValueDictionary new.
	self
		should: [ 1 to: ZnConstants maximumNumberOfDictionaryEntries + 1 do: [ :each | 
						dictionary at: each put: each ] ]
		raise: ZnTooManyDictionaryEntries! !

TestCase subclass: #ZnRequestLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:08'!
testReading
	| requestLine string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.1', String crlf.
	requestLine := ZnRequestLine readFrom: string readStream.
	self assert: requestLine method = #GET.
	self assert: requestLine uriPathQueryFragment = '/foo/bar/xyz.txt'.
	self assert: requestLine version = ZnConstants defaultHTTPVersion ! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:04'!
testReadingWrongMethod
	| string |
	string := 'GETT /foo/bar/xyz.txt HTTP/1.1', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknownHttpMethod! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion
	| string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.5', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| requestLine string |
	requestLine := ZnRequestLine method: 'GET' uri: '/foo/bar/xyz.txt'.
	string := String streamContents: [ :stream | requestLine writeOn: stream ].
	self assert: string = ('GET /foo/bar/xyz.txt HTTP/1.1', String crlf)! !

TestCase subclass: #ZnRequestTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 20:25'!
testBasicAuthenticate
	| request |
	request := ZnRequest new.
	request setBasicAuthenticationUsername: 'user' password: 'secret'.
	self assert: (request headers at: 'Authorization') = 'Basic dXNlcjpzZWNyZXQ='! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/4/2012 21:40'!
testCookiesParsing
	| input request cookies testCookie1 testCookie2 |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Cookie: testCookie1=123; testCookie2=321', String crlf,
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	
	cookies := request cookies.
	testCookie1 := cookies detect: [ :each | each name = 'testCookie1' ].
	testCookie2 := cookies detect: [ :each | each name = 'testCookie2' ].
	
	self assert: testCookie1 notNil.
	self assert: testCookie1 value = '123'.	
	
	self assert: testCookie2 notNil.
	self assert: testCookie2 value = '321'.	

! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/4/2012 23:18'!
testCookiesWriting
	|  client testCookie1 testCookie2 cookieString cookies|
	client := ZnClient new.
	client url: 'http://www.example.com'.
	(testCookie1 := ZnCookie name: 'testCookie1' value: '123')
		domain: 'example.com'.
	(testCookie2 := ZnCookie name: 'testCookie2' value: '321')
		domain: 'example.com'.
	(client session cookieJar)
		add: testCookie1;
		add: testCookie2.
	client sendCookies.
	cookies := client request cookies do: [ :each | each defaultDomain: 'example.com' ].
	self assert: (cookies includes: testCookie1).
	self assert: (cookies includes: testCookie2)
	
		
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:34'!
testReading
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: (request headers at: 'Host') = 'foo.com'.
	self assert: request hasEntity not
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:35'!
testReadingWithEntity
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Content-Length: 8', String crlf, 
		'Content-Type: text/plain', String crlf, 
		String crlf, 
		'12345678'.
	request := ZnRequest readFrom: input asByteArray readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: request contentType = ZnMimeType textPlain.
	self assert: request contentLength = 8.
	self assert: request hasHeaders.
	self assert: request entity contents = '12345678'
! !

TestCase subclass: #ZnResponseTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnResponseTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 11:30'!
testCookie
	| response cookie1  responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	response addCookie: cookie1.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie1=123')	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 11:30'!
testCookies
	| response cookie1 cookie2 responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	cookie2 := ZnCookie new.
	cookie2 
		name: 'testCookie2';
		value: '321'.
		
	response addCookie: cookie1.
	response addCookie: cookie2.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie1=123').  
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie2=321').  	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testCreated
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse created: uri.
	self assert: response code = 201.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testNotFound
	| response |
	response := ZnResponse notFound: 'http:///secret.txt'.
	self assert: response code = 404.
	self assert: (response headers includesKey: 'Server').
	self assert: (response headers includesKey: 'Date').
	self assert: (response entity contents includesSubString: 'secret.txt')! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testRedirect
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse redirect: uri.
	self assert: response code = 302.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2011 22:18'!
testSlashdotGzipChunked
	| request stream response contents |
	(request := ZnRequest get: 'http://slashdot.org')
		setConnectionClose;
		setAcceptEncodingGzip.
	stream := ZnNetworkingUtils socketStreamToUrl: request url.
	response := [ 
  		request writeOn: stream. 
  		stream flush. 
  		ZnResponse readFrom: stream ] ensure: [ stream close ].
	response isRedirect ifTrue: [ ^ self ].
	self assert: response code = 200.
	self assert: ((response headers at: 'Content-Type') beginsWith: 'text/html').
	self assert: (response headers at: 'Content-Encoding' ifAbsent: [ 'gzip' ]) = 'gzip'.
	self assert: (response headers at: 'Transfer-Encoding' ifAbsent: [ 'chunked' ]) = 'chunked'.
	contents := response entity contents.
	self assert: ((contents includesSubString: 'Slashdot') or: [ contents includesSubString: 'refresh' ])
! !

!ZnResponseTests methodsFor: 'as yet unclassified' stamp: 'SvenVanCaekenberghe 12/3/2010 21:29'!
testWritingBinary
	| response bytes string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	bytes := ByteArray streamContents: [ :stream | response writeOn: stream ].
	string := bytes asString.
	self assert: (string includesSubString: '200 OK').
	self assert: (string includesSubString: 'Okay')! !

!ZnResponseTests methodsFor: 'as yet unclassified' stamp: 'SvenVanCaekenberghe 12/3/2010 21:30'!
testWritingCharacter
	| response string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	string := String streamContents: [ :stream | response writeOn: stream ].
	self assert: (string includesSubString: '200 OK').
	self assert: (string includesSubString: 'Okay')! !

TestCase subclass: #ZnServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnServerTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:36'!
port
	^ 1700 + 10 atRandom! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:39'!
testAuthorizationFailed
	self withServerDo: [ :server | | response |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		response := ZnEasy get: (server localUrl addPathSegment: 'echo'; yourself).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Zinc') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:41'!
testAuthorizationSuccessful
	self withServerDo: [ :server | | response |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself) username: 'foo' password: 'secret'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 22:06'!
testDefault
	| port server |
	ZnServer stopDefault.
	self assert: ZnServer default isNil.
	port := self port.
	server := ZnServer startDefaultOn: port.
	self assert: ZnServer default notNil.
	self assert: ZnServer default == server.
	self assert: ZnServer default port = port.
	self assert: ZnServer default isRunning.
	self assert: (ZnServer managedServers includes: server).
	ZnServer stopDefault.
	self assert: ZnServer default isNil.
	self deny: server isRunning.
	self deny: (ZnServer managedServers includes: server).
	server := ZnServer startDefaultOn: port.
	"Starting the default again is actually a restart"
	ZnServer startDefaultOn: port.
	self assert: ZnServer default == server.
	ZnServer stopDefault! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:42'!
testEcho
	self withServerDo: [ :server | | response |
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity contents includesSubString: 'Zinc').
		self assert: (response entity contents includesSubString: 'foo') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:44'!
testEchoLocalInterface
	| server response |
	(server := ZnServer on: self port)
		interface: NetNameResolver loopBackAddress.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity contents includesSubString: 'Zinc').
		self assert: (response entity contents includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:44'!
testGetUnicodeUtf8
	self withServerDo: [ :server | | response html |
		response := ZnEasy get: (server localUrl addPathSegment: 'unicode'; yourself).
		self assert: (response contentType = ZnMimeType textHtml).
		self assert: (response statusLine code = 200).
		self assert: response contentType isCharSetUTF8.
		html := response entity contents.
		self assert: (html includesSubString: 'Unicode').
		0 to: 16r024F do: [ :each | self assert: (html includes: each asCharacter) ] ]! !

!ZnServerTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:36'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnStatusLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:09'!
testReading
	| statusLine string |
	string := 'HTTP/1.1 200 OK', String crlf.
	statusLine := ZnStatusLine readFrom: string readStream.
	self assert: statusLine code = 200.
	self assert: statusLine reason = 'OK'.
	self assert: statusLine version = ZnConstants defaultHTTPVersion ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:04'!
testReadingWrongCode
	| string |
	string := 'HTTP/1.0 1000 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpStatusCode ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion
	| string |
	string := 'HTTP/0.9 200 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion2
	| string |
	string := 'HTTP/0.9 Foo OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 09:03'!
testWriting
	| statusLine string |
	statusLine := ZnStatusLine ok.
	string := String streamContents: [ :stream | statusLine writeOn: stream ].
	self assert: string = ('HTTP/1.1 200 OK', String crlf)! !

TestCase subclass: #ZnUrlTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:40'!
testAsZnUrl
	| url1 url2 url3 |
	url1 := 'http://www.example.com:8080/foo/bar/doc.txt?x=1&y=2#mark'.
	self assert: url1 asZnUrl = url1 asUrl asZnUrl.
	url2 := 'http://www.google.com'.
	self assert: url2 asZnUrl = url2 asUrl asZnUrl.
	url3 := 'http://www.google.com?q=Pharo'.
	self assert: url3 asZnUrl = url3 asUrl asZnUrl.
	"self assert: '' asZnUrl = '' asUrl asZnUrl."
	"self assert: '/' asZnUrl = '/' asUrl asZnUrl."

! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:05'!
testAuthority
	self assert: 'http://localhost:8080/foo/bar/doc.txt' asZnUrl authority = 'localhost:8080'.
	self assert: 'http://www.google.com?q=Smalltalk' asZnUrl authority = 'www.google.com'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:13'!
testDefaultScheme
	| url |
	url := ZnUrl fromString: 'www.example.com/foo.html' defaultScheme: #http.  
	self assert: url hasScheme.
	self assert: url scheme = #http.
	self assert: url host = 'www.example.com'.
	self assert: url pathSegments = (OrderedCollection with: 'foo.html')
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:14'!
testDefaultSchemeAndPort
	| url |
	url := '' asZnUrl.
	self assert: url hasScheme not.
	self assert: url hasPort not.
	self assert: url port isNil.
	self assert: url scheme isNil.
	self assert: url schemeOrDefault = #http.
	self assert: url portOrDefault = 80
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:14'!
testDefaults
	| url |
	url := '' asZnUrl asZnUrlWithDefaults.
	self assert: url hasScheme.
	self assert: url hasPort.
	self assert: url scheme = #http.
	self assert: url port = 80
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/17/2011 10:29'!
testEncodedSlash
	self assert: 'http://example.com/foo//' asZnUrl pathPrintString = '/foo/'.
	self assert: 'http://example.com/foo//bar/' asZnUrl pathPrintString = '/foo/bar/'.
	self assert: 'http://example.com/foo//bar/file.txt' asZnUrl pathPrintString = '/foo/bar/file.txt'.

	self assert: 'http://example.com/foo/%2F' asZnUrl pathPrintString = '/foo/%2F'.
	self assert: 'http://example.com/foo/%2Fbar/' asZnUrl pathPrintString = '/foo/%2Fbar/'.
	self assert: 'http://example.com/foo/%2F/bar/' asZnUrl pathPrintString = '/foo/%2F/bar/'.
	self assert: 'http://example.com/foo/%2Ffoo.txt' asZnUrl pathPrintString = '/foo/%2Ffoo.txt'.

! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:42'!
testIsSlash
	self assert: '' asZnUrl isSlash.
	self assert: '/' asZnUrl isSlash.
	self assert: '/foo' asZnUrl isSlash not.
	self assert: 'http://host/foo' asZnUrl isSlash not.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/13/2011 10:44'!
testLocalHost
	self assert: 'http://localhost:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://127.0.0.1:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://LOCALHOST:8080/foo' asZnUrl isLocalHost.
	self deny: 'http://zn.stx.eu' asZnUrl isLocalHost.
	self deny: '' asZnUrl isLocalHost.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 14:55'!
testMissingScheme
	| url |
	url := 'www.example.com' asZnUrl.
	self assert: url hasHost not.
	self assert: url pathSegments = (OrderedCollection with: 'www.example.com')
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:20'!
testParsePathOnly
	| url |
	url := '/images/foo.png?size=large#center' asZnUrl.
	self assert: url hasScheme not.
	self assert: url hasHost not.
	self assert: url hasPort not.
	self assert: url isAbsolute not.
	self assert: url pathSegments = (OrderedCollection with: 'images' with: 'foo.png' ).
	self assert: url firstPathSegment = 'images'.
	self assert: url lastPathSegment = 'foo.png'.
	self assert: url hasQuery.
	self assert: (url queryAt: 'size') = 'large'.
	self assert: url hasFragment.
	self assert: url fragment = 'center'  ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 12:17'!
testParsingEmpty
	| url |
	url := ZnUrl fromString: ''.
	self assert: url isEmpty.
	url := ZnUrl fromString: '/'.
	self assert: url isEmpty.
	url := ZnUrl fromString: '//./foo/../'.
	self assert: url isEmpty! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:36'!
testParsingEscape
	| url |
	url := ZnUrl fromString: 'http://localhost/foo%62%61%72'.
	self assert: url firstPathSegment = 'foobar'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/3/2011 16:41'!
testParsingSimple
	| url |
	url := ZnUrl fromString: 'http://www.example.com:8080/foo/bar/baz.txt?x=1&y=2#m1'.
	self assert: url scheme = #http.
	self assert: url host = 'www.example.com'.
	self assert: url port = 8080.
	self assert: url hasPath.
	self assert: url isFile.
	self assert: url hasQuery.
	self assert: url hasFragment.
	self assert: url fragment = 'm1'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:50'!
testParsingWrongEscape
	self should: [ ZnUrl fromString: 'http://foo:8080/foo%%bar' ] raise: ZnPercentEncodingWrong ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:55'!
testParsingWrongEscapeQuery
	self should: [ ZnUrl fromString: 'http://foo:8080/foo?%%bar=1' ] raise: ZnPercentEncodingWrong ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:28'!
testParsingWrongPort
	self should: [ ZnUrl fromString: 'http://foo:bar' ] raise: ZnPortNotANumber   ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testParsingWrongScheme
	self should: [ ZnUrl fromString: 'htttp://foo:bar' ] raise: ZnUnknownScheme ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 12:21'!
testPrintingSimple
	| url |
	(url := ZnUrl new)
		scheme: #http;
		host: 'www.seaside.st';
		port: 8080;
		addPathSegment: 'example';
		addPathSegment: 'foo.html';
		queryAt: 'q' put: '100';
		fragment: 'mark'.
	self assert: url authority = 'www.seaside.st:8080'.
	self assert: url isAbsolute.
	self assert: url isFile.
	self assert: url printString = 'http://www.seaside.st:8080/example/foo.html?q=100#mark'.
	self assert: url file = 'foo.html'.
	self assert: url directory = 'example'.
	self assert: url pathPrintString = '/example/foo.html'.
	self assert: url pathQueryFragmentPrintString = '/example/foo.html?q=100#mark'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:26'!
testQuery
	| url |
	url := 'http://foo.com/test?q' asZnUrl.
	self assert: url printString = 'http://foo.com/test?q'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/13/2011 14:16'!
testQueryEncoding
	| url |
	url := 'http://www.google.com' asZnUrl.
	url addPathSegment: 'some encoding here'.
	url queryAt: 'and some encoding' put: 'here, too'.
	self assert: url printString = 'http://www.google.com/some%20encoding%20here?and%20some%20encoding=here%2C%20too'.
	self assert: url path =  'some encoding here'.
	self assert: (url queryAt: 'and some encoding') = 'here, too'
	! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/13/2011 14:14'!
testQueryManipulation
	| url |
	url := 'http://www.google.com/?one=1&two=2' asZnUrl.
	url queryAt: 'three' put: '3'.
	url queryRemoveKey: 'one'.
	self assert: url queryKeys sorted = #(three two).
	self assert: (url queryAt: 'two') = '2'.
	self assert: (url queryAt: 'three') = '3'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/11/2011 15:10'!
testRelative
	| url |
	url := 'http://api.foo.com:8080' asZnUrl.
	self assert: url isAbsolute.
	url parseFrom: '/user/1?format=full'.
	self assert: url printString = 'http://api.foo.com:8080/user/1?format=full'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/24/2012 11:44'!
testRetrieveContents
	| numbers |
	numbers := 'http://zn.stfx.eu/zn/numbers.txt' asZnUrl retrieveContents.
	numbers := numbers lines collect: [ :each | each asInteger ].
	self assert: (numbers allSatisfy: [ :each | each isInteger ]).
	self should: [ 'http://zn.stfx.eu/zn/numbers-wrong.txt' asZnUrl retrieveContents ] raise: Error! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:57'!
testWriteUrlPathQueryFragmentOfOn
	| string |
	string := String streamContents: [ :stream |
		'http://host:7777/foo/bar/doc.txt?x=1#mark' asZnUrl printPathQueryFragmentOn:  stream ].
	self assert: string = '/foo/bar/doc.txt?x=1#mark'! !

TestCase subclass: #ZnUserAgentSessionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentSessionTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:11'!
dummyCredential
	^ZnBasicCredential new 
		username: 'test'; 
		password: 'foobar';
		realm: 'dummy';
		domain: 'test.com';
		yourself! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2011 22:00'!
testAccessors
	| session |
	session := ZnUserAgentSession new.
	self assert: (session cookieJar isKindOf: ZnCookieJar).
	self assert: (session credentials notNil)! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:14'!
testAddCredential
	| session count |
	session := ZnUserAgentSession new.
	count := session credentials size.
	session addCredential: self dummyCredential.
	self assert: ((session credentials size) = (count + 1))! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testWithCookieJar
	self assert: ((ZnUserAgentSession withCookieJar: ZnCookieJar new) notNil)! !

TestCase subclass: #ZnUserAgentSettingsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:58'!
testAccessors
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings agent notNil).
	self assert: (settings followRedirect isKindOf: Boolean).
	self assert: (settings redirectLimit notNil).
	self assert: (settings timeout notNil)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testClassDefaults
	self assert: (ZnUserAgentSettings defaultCookieJar new isKindOf: ZnCookieJar).
	self assert: (ZnUserAgentSettings defaultSessionClass new isKindOf: ZnUserAgentSession).
	self assert: (ZnUserAgentSettings defaultSettingsClass new isKindOf: ZnUserAgentSettings)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:59'!
testLoadSession
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings loadSession isKindOf: ZnUserAgentSession)! !

TestCase subclass: #ZnUserAgentTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 10/4/2011 14:11'!
ignoringDeprecation: block
	[ block value ] 
		on: Deprecation 
		do: [ :exception | exception resume ]! !

!ZnUserAgentTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:48'!
port
	^ 1700 + 10 atRandom! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:48'!
testCookieAt
	self ignoringDeprecation: [ | url client response |
		url := 'http://www.google.com/' asZnUrl.
		client := ZnUserAgent new.
		response := client get: url.
		self assert: (client cookieAt: 'PREF') notNil ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:49'!
testDelete
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response client |
			client := ZnUserAgent new.
			response := client delete: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 200.
			self assert: (response entity string includesSubString: 'DELETE').
			self assert: (response entity string includesSubString: 'foo') ] ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:50'!
testErrorHandler
	self ignoringDeprecation: [ | client flag |
		flag := false.
		client := ZnUserAgent new errorHandler: [ :error | flag := true ].
		client get: ''.
		self assert: flag ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:50'!
testFollowRedirect
	self ignoringDeprecation: [ | url client response |
		url := 'http://www.pharo-project.org/' asZnUrl.
		client := ZnUserAgent new.
		client settings followRedirect: false.
		response := client get: url.
		self assert: response isRedirect.
		client settings followRedirect: true.
		response := client get: url.
		self assert: response isSuccess ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:50'!
testGetSmallHTMLDocument
	self ignoringDeprecation: [ | url response |
		url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
		response := ZnUserAgent new get: url.
		self assert: response headers contentType = ZnMimeType textHtml.
		self assert: response statusLine code = 200.
		self assert: (response entity string includesSubString: 'small') ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:50'!
testHeadSmallHTMLDocument
	self ignoringDeprecation: [ | url response |
		url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
		response := ZnUserAgent new head: url.
		self assert: response headers contentType = ZnMimeType textHtml.
		self assert: response statusLine code = 200 ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:51'!
testPost
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response data client |
			data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
			client := ZnUserAgent new.
			response := client 
				post: (server localUrl addPathSegments: #('echo' 'foo'); yourself) 
				data: (ZnEntity text: data).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 200.
			self assert: (response entity string includesSubString: 'POST').
			self assert: (response entity string includesSubString: data) ] ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:52'!
testPut
	self ignoringDeprecation: [ 
		self withServerDo: [ :server | | response data client |
			data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
			client := ZnUserAgent new.
			response := client 
				put: (server localUrl addPathSegments: #('echo' 'foo'); yourself) 
				data: (ZnEntity text: data).
			self assert: response headers contentType = ZnMimeType textPlain.
			self assert: response statusLine code = 200.
			self assert: (response entity string includesSubString: 'PUT').
			self assert: (response entity string includesSubString: data) ] ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:58'!
testRelativeRedirect
	self ignoringDeprecation: [
		self withServerDo: [ :server | |  response client |
			server delegate:
				(ZnValueDelegate with: [ :request | 
					request uri firstPathSegment = 'one'
						ifTrue: [ ZnResponse redirect: 'two' ]
						ifFalse: [ 
							request uri firstPathSegment = 'two'
								ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
								ifFalse: [ ZnResponse notFound: request uri ] ] ]).
			client := ZnUserAgent new.
			response := client 
				post: (server localUrl addPathSegment: 'one'; yourself) 
				data: (ZnEntity text: 'data').
			self assert: response isSuccess.
			self assert: response contents = 'OK!!' ] ]! !

!ZnUserAgentTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:48'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/21/2011 20:25'!
testBase64
	| short long encoded legalCharactes |
	legalCharactes := (String withAll: ($A to: $Z), ($a to: $z), ($0 to: $9)), '='.
	short := String withAll: ((1 to: 16) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: short.
	self assert: (ZnUtils decodeBase64: encoded) = short.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ]).
	"We don't want line breaks!!"
	long := String withAll: ((1 to: 64) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: long.
	self assert: (ZnUtils decodeBase64: encoded) = long.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ])
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:09'!
testCapitalizeString
	self assert: (ZnUtils capitalizeString: 'content-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'CONTENT-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'content-TYPE') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'WWW-Authenticate') = 'Www-Authenticate'.
	self assert: (ZnUtils capitalizeString: 'Content-MD5') = 'Content-Md5'.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testHttpDate
	| timestamp string |
	timestamp := (DateAndTime year: 2010 month: 9 day: 1 hour: 10 minute: 10 second: 10 offset: 0 seconds).
	string := ZnUtils httpDate: timestamp.
	self assert: (string = 'Wed, 01 Sep 2010 10:10:10 GMT')
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:10'!
testIsCapitalizedString
	self assert: (ZnUtils isCapitalizedString: 'Content-Type').
	self assert: (ZnUtils isCapitalizedString: 'CONTENT-type') not.
	self assert: (ZnUtils isCapitalizedString: 'content-TYPE') not.
	self assert: (ZnUtils isCapitalizedString: 'WWW-Authenticate') not.
	self assert: (ZnUtils isCapitalizedString: 'Connection')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2011 11:48'!
testParseHttpDate
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue, 13 Sep 2011 08:04:49 GMT'.
	self assert: timeStamp dayOfMonth = 13.
	self assert: timeStamp monthIndex = 9.
	self assert: timeStamp year = 2011.
	self assert: timeStamp hour = 8.
	self assert: timeStamp minute = 4.
	self assert: timeStamp second = 49.
	self assert: timeStamp offset = 0.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2011 11:49'!
testParseHttpDateAlternative1
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue Jan 01 00:00:01 2036 GMT'.
	self assert: timeStamp dayOfMonth = 1.
	self assert: timeStamp monthIndex = 1.
	self assert: timeStamp year = 2036.
	self assert: timeStamp hour = 0.
	self assert: timeStamp minute = 0.
	self assert: timeStamp second = 1.
	self assert: timeStamp offset = 0.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/13/2011 11:49'!
testParseHttpDateDashes
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue, 13-Sep-2011 08:04:49 GMT'.
	self assert: timeStamp dayOfMonth = 13.
	self assert: timeStamp monthIndex = 9.
	self assert: timeStamp year = 2011.
	self assert: timeStamp hour = 8.
	self assert: timeStamp minute = 4.
	self assert: timeStamp second = 49.
	self assert: timeStamp offset = 0.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/11/2010 21:36'!
testQueryParsing
	| string fields |
	string := 'foo=100&x=', ('/a b' encodeForHTTP).
	fields := ZnUtils parseQueryFrom: string readStream.
	self assert: (fields at: 'foo') = '100'.
	self assert: (fields at: 'x') = '/a b'.
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:55'!
testQueryWriting
	| fields string |
	(fields := Dictionary new)
		at: 'foo' put: '100';
		at: 'bar' put: 'a b'.
	string := String streamContents: [ :stream | ZnUtils writeQueryFields: fields on: stream ].
	self assert: (string includesSubString: 'foo=1').
	self assert: (string includesSubString: 'bar=a%20b').! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:57'!
testReadUpToEndBinary
	| data |
	data := ByteArray streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: #(1 2 3) atRandom ] ].
	self assert: (ZnUtils readUpToEnd: data readStream limit: nil) = data.
	self assert: (ZnUtils readUpToEnd: data readStream limit: 10000) = data.
	self should: [ ZnUtils readUpToEnd: data readStream limit: 9999 ] raise: ZnEntityTooLarge 
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:58'!
testReadUpToEndNonBinary
	| data |
	data := String streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: 'abc' atRandom ] ].
	self assert: (ZnUtils readUpToEnd: data readStream limit: nil) = data.
	self assert: (ZnUtils readUpToEnd: data readStream limit: 10000) = data.
	self should: [ ZnUtils readUpToEnd: data readStream limit: 9999 ] raise: ZnEntityTooLarge 
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:56'!
testStreamingBinary
	| data in out |
	data := ByteArray streamContents: [ :stream | 
		1 to: 10000 do: [ :each |
			stream nextPut: #(1 2 3) atRandom ] ].
	in := data readStream.
	out := WriteStream on: (ByteArray new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:56'!
testStreamingNonBinary
	| data in out |
	data := String streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: 'abc' atRandom ] ].
	in := data readStream.
	out := WriteStream on: (String new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !
